from tests.fixtures import *
import vault.vault as vault

def test_unlock(vault_data_locked):
    v = vault.Vault()
    v.data = vault_data_locked
    v._locked = True
    v.unlock('testpass')
    assert 'test' in v.data['vault']

def test_already_unlocked(vault_data_unlocked):
    v = vault.Vault()
    v.data = vault_data_unlocked
    v.unlock('testpass')
    assert 'test' in v.data['vault']
    
def test_lock():
    pass



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="acid_vault",
    version="0.0.2",
    author="Nils Nyman-Waara",
    author_email="acid_vault@h2so4.se",
    description="Password Vault",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/svavelsyra/PyVault",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Affero General Public License v3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=['cryptography>=3.0',
                      'paramiko>=2.7',
                      'pillow>=7.0']
)
